@@ -11,11 +11,11 @@
       PARAMETER (WUNIT=24)
 
       REAL      WX1(NWX),WX2(NWX)
-      LOGICAL   LCNTL, SYSFONT, LFPROP, MARKFONT
+      LOGICAL   LCNTL, LSYSFNT, LFPROP, LMRKFNT,LCNTLZ
       CHARACTER CSGI*1,CSUP*1,CSUB*1,CRST*1
       CHARACTER FONTNAME*70
       REAL      SMALL, SHIFT
-      INTEGER   ISUB, ISUP, IRST, IFONT, INDEX
+      INTEGER   ISUBZ, ISUPZ, IRSTZ, IFONT, INDEX
 
       EXTERNAL  LENC,INDXCF,NINDXC,CSGI,ISGC
 
@@ -37,8 +37,8 @@
 
 *     / FOR SYSTEM FONTS /
 *     / PROCCESS IF NOT MARKER /
-      CALL SWLGET("SYSFONT", SYSFONT)
-      IF(SYSFONT) THEN
+      CALL SWLGET("LSYSFNT", LSYSFNT)
+      IF(LSYSFNT) THEN
       CALL SZQIDX(INDEX)
       CALL SWCGET("FONTNAME",FONTNAME)
 *     / WHEN FONTNAME IS NOT GIVEN /
@@ -62,8 +62,8 @@
 
 
       IDX=ISGC(CHARS(1:1))
-      CALL SGLGET('MARKFONT',MARKFONT)
-      IF (IDX.GT.18 .OR. MARKFONT) THEN
+      CALL SGLGET('LMRKFNT',LMRKFNT)
+      IF (IDX.GT.18 .OR. LMRKFNT) THEN
         IF (IDX.LT.18) THEN
           CALL SWSFW(MAX(MOD(INDEX,10),1))
         END IF
@@ -76,20 +76,24 @@
 *     / CHECK LCNTL OPTION /
 
       CALL SGLGET('LCNTL',LCNTL)
+      LCNTLZ=.TRUE.
 
-      IF (LCNTL) THEN
+      IF (LCNTLZ) THEN
 
 *       / CONTROL CHARACTERS ARE EFFECTIVE /
 
-        CALL SGIGET('ISUP',ISUP)
-        CALL SGIGET('ISUB',ISUB)
-        CALL SGIGET('IRST',IRST)
+*        CALL SGIGET('ISUP',ISUP)
+*        CALL SGIGET('ISUB',ISUB)
+*        CALL SGIGET('IRST',IRST)
         CALL SGRGET('SMALL',SMALL)
         CALL SGRGET('SHIFT',SHIFT)
 
-        CSUP=CSGI(ISUP)
-        CSUB=CSGI(ISUB)
-        CRST=CSGI(IRST)
+        ISUPZ=29
+        ISUBZ=30
+        IRSTZ=31
+        CSUP=CSGI(ISUPZ)
+        CSUB=CSGI(ISUBZ)
+        CRST=CSGI(IRSTZ)
 
         NC=0
         NCTL=0
@@ -148,10 +152,10 @@
         DO 20 N=1,NCHZ
           ICH=ISGC(CHARS(N:N))
           IDX=ICH+1
-          IF (ICH.EQ.ISUP .OR. ICH.EQ.ISUB) THEN
+          IF (ICH.EQ.ISUPZ .OR. ICH.EQ.ISUBZ) THEN
             RFACT=SMALL
             GO TO 20
-          ELSE IF (ICH.EQ.IRST) THEN
+          ELSE IF (ICH.EQ.IRSTZ) THEN
             RFACT=1
             GO TO 20
           END IF
