@@ -152,6 +152,10 @@
       LMARK=.TRUE.
       DO 3 N=1,NCZ
         IDX0=ISGC(CHARX(N:N))
+        IF(IDX0.EQ.ISUPZ .OR. IDX0.EQ.ISUBZ .OR. IDX0.EQ.IRSTZ)THEN
+          CHARX(N:N)=CSGI(32)
+          IDX0=ISGC(CHARX(N:N))
+        END IF
         IF(IMODE.EQ.1)THEN
           IF (IDX0.EQ.94)THEN
             LCNTLZ=.TRUE.
