@@ -10,7 +10,7 @@
       LOGICAL LEXP, LCNTL, LSFNT
 
       CALL SGLGET('LCNTL', LCNTL)
-      CALL SWLGET('SYSFONT',LSFNT)
+      CALL SWLGET('LSYSFNT',LSFNT)
       CALL GLRGET('REPSL', PREC)
       NPREC = -LOG10(PREC)
       IF(NPREC.GT.8) NPREC = 8
